# IO Utils

```{eval-rst}
.. autoclass:: pyqrlew.io.PostgreSQL
    :members: extract, financial, hepatitis, imdb, retail, load_extract, load_financial, load_hepatitis, load_imdb, load_retail
```

```{eval-rst}
.. autoclass:: pyqrlew.io.SQLite
    :members:
```

```{eval-rst}
.. autofunction:: pyqrlew.io.dataset.dataset_from_database
```
